@@ -1,3 +1,4 @@
+import warnings
 from typing import Sequence
 
 from numpy import isscalar
@@ -6,18 +7,19 @@ from numpy import newaxis
 from numpy import vstack
 from numpy import zeros
 from scipy.integrate import odeint
+from scipy.linalg import LinAlgWarning
 from sklearn.base import BaseEstimator
-from sklearn.exceptions import NotFittedError
+from sklearn.exceptions import ConvergenceWarning
 from sklearn.metrics import r2_score
-from sklearn.multioutput import MultiOutputRegressor
 from sklearn.pipeline import Pipeline
 from sklearn.preprocessing import PolynomialFeatures
 from sklearn.utils.validation import check_is_fitted
 
 from pysindy.differentiation import FiniteDifference
+from pysindy.optimizers import SINDyOptimizer
 from pysindy.optimizers import STLSQ
 from pysindy.utils.base import drop_nan_rows
-from pysindy.utils.base import equation
+from pysindy.utils.base import equations
 from pysindy.utils.base import validate_input
 
 
@@ -105,7 +107,9 @@ class SINDy(BaseEstimator):
         self.discrete_time = discrete_time
         self.n_jobs = n_jobs
 
-    def fit(self, x, t=1, x_dot=None, multiple_trajectories=False):
+    def fit(
+        self, x, t=1, x_dot=None, multiple_trajectories=False, unbias=True, quiet=False
+    ):
         """
         Fit the SINDy model.
 
@@ -141,6 +145,20 @@ class SINDy(BaseEstimator):
             for each trajectory. If False, the training data must be a single
             array.
 
+        unbias: boolean, optional (default True)
+            Whether to perform an extra step of unregularized linear regression to
+            unbias the coefficients for the identified support.
+            If the optimizer (`SINDy.optimizer`) applies any type of regularization,
+            that regularization may bias coefficients toward particular values,
+            improving the conditioning of the problem but harming the quality of the
+            fit. Setting `unbias=True` enables an extra step wherein unregularized
+            linear regression is applied, but only for the coefficients in the support
+            identified by the optimizer. This helps to remove the bias introduced by
+            regularization.
+
+        quiet: boolean, optional (default False)
+            Whether or not to suppress warnings during model fitting.
+
         Returns
         -------
         self: returns an instance of self
@@ -165,15 +183,20 @@ class SINDy(BaseEstimator):
         # Drop rows where derivative isn't known
         x, x_dot = drop_nan_rows(x, x_dot)
 
-        steps = [("features", self.feature_library), ("model", self.optimizer)]
-        self.model = MultiOutputRegressor(Pipeline(steps), n_jobs=self.n_jobs)
+        optimizer = SINDyOptimizer(self.optimizer, unbias=unbias)
+        steps = [("features", self.feature_library), ("model", optimizer)]
+        self.model = Pipeline(steps)
 
-        self.model.fit(x, x_dot)
+        action = "ignore" if quiet else "default"
+        with warnings.catch_warnings():
+            warnings.filterwarnings(action, category=ConvergenceWarning)
+            warnings.filterwarnings(action, category=LinAlgWarning)
+            warnings.filterwarnings(action, category=UserWarning)
 
-        self.n_input_features_ = self.model.estimators_[0].steps[0][1].n_input_features_
-        self.n_output_features_ = (
-            self.model.estimators_[0].steps[0][1].n_output_features_
-        )
+            self.model.fit(x, x_dot)
+
+        self.n_input_features_ = self.model.steps[0][1].n_input_features_
+        self.n_output_features_ = self.model.steps[0][1].n_output_features_
 
         if self.feature_names is None:
             feature_names = []
@@ -201,16 +224,13 @@ class SINDy(BaseEstimator):
         x_dot: array-like or list of array-like, shape (n_samples, n_input_features)
             Predicted time derivatives
         """
-        if hasattr(self, "model"):
-            if multiple_trajectories:
-                x = [validate_input(xi) for xi in x]
-                return [self.model.predict(xi) for xi in x]
-            else:
-                x = validate_input(x)
-                if hasattr(self, "model"):
-                    return self.model.predict(x)
+        check_is_fitted(self, "model")
+        if multiple_trajectories:
+            x = [validate_input(xi) for xi in x]
+            return [self.model.predict(xi) for xi in x]
         else:
-            raise NotFittedError("SINDy model must be fit before predict can be called")
+            x = validate_input(x)
+            return self.model.predict(x)
 
     def equations(self, precision=3):
         """
@@ -227,20 +247,14 @@ class SINDy(BaseEstimator):
         equations: list of strings
             Strings containing the SINDy model equation for each input feature.
         """
-        if hasattr(self, "model"):
-            check_is_fitted(self.model.estimators_[0].steps[-1][1])
-            if self.discrete_time:
-                base_feature_names = [f + "[k]" for f in self.feature_names]
-            else:
-                base_feature_names = self.feature_names
-            return [
-                equation(est, input_features=base_feature_names, precision=precision)
-                for est in self.model.estimators_
-            ]
+        check_is_fitted(self, "model")
+        if self.discrete_time:
+            base_feature_names = [f + "[k]" for f in self.feature_names]
         else:
-            raise NotFittedError(
-                "SINDy model must be fit before equations can be called"
-            )
+            base_feature_names = self.feature_names
+        return equations(
+            self.model, input_features=base_feature_names, precision=precision
+        )
 
     def print(self, lhs=None, precision=3):
         """Print the SINDy model equations.
@@ -416,27 +430,16 @@ class SINDy(BaseEstimator):
     def coefficients(self):
         """Return a list of the coefficients learned by SINDy model.
         """
-        if hasattr(self, "model"):
-            check_is_fitted(self.model.estimators_[0].steps[-1][1])
-            return vstack([est.steps[-1][1].coef_ for est in self.model.estimators_]).T
-        else:
-            raise NotFittedError(
-                "SINDy model must be fit before coefficients is called"
-            )
+        check_is_fitted(self, "model")
+        return self.model.steps[-1][1].coef_
 
     def get_feature_names(self):
         """Return a list of names of features used by SINDy model.
         """
-        if hasattr(self, "model"):
-            return (
-                self.model.estimators_[0]
-                .steps[0][1]
-                .get_feature_names(input_features=self.feature_names)
-            )
-        else:
-            raise NotFittedError(
-                "SINDy model must be fit before get_feature_names is called"
-            )
+        check_is_fitted(self, "model")
+        return self.model.steps[0][1].get_feature_names(
+            input_features=self.feature_names
+        )
 
     def simulate(self, x0, t, integrator=odeint, stop_condition=None, **integrator_kws):
         """
@@ -496,4 +499,4 @@ class SINDy(BaseEstimator):
 
     @property
     def complexity(self):
-        return sum(est.steps[1][1].complexity for est in self.model.estimators_)
+        return self.model.steps[-1][1].complexity
