@@ -1,6 +1,7 @@
 from itertools import repeat
 
 import numpy as np
+from sklearn.base import MultiOutputMixin
 from sklearn.utils.validation import check_array
 
 # Define a special object for the default value of t in
@@ -135,10 +136,27 @@ def print_model(
     return eq
 
 
-def equation(pipeline, input_features=None, precision=3, input_fmt=None):
+def equations(pipeline, input_features=None, precision=3, input_fmt=None):
     input_features = pipeline.steps[0][1].get_feature_names(input_features)
     if input_fmt:
         input_features = [input_fmt(i) for i in input_features]
     coef = pipeline.steps[-1][1].coef_
     intercept = pipeline.steps[-1][1].intercept_
-    return print_model(coef, input_features, intercept=intercept, precision=precision)
+    if np.isscalar(intercept):
+        intercept = intercept * np.ones(coef.shape[0])
+    return [
+        print_model(
+            coef[i], input_features, intercept=intercept[i], precision=precision
+        )
+        for i in range(coef.shape[0])
+    ]
+
+
+def supports_multiple_targets(estimator):
+    """Checkes whether estimator support mutliple targets."""
+    if isinstance(estimator, MultiOutputMixin):
+        return True
+    try:
+        return estimator._more_tags()["multioutput"]
+    except (AttributeError, KeyError):
+        return False
